@@ -21,7 +21,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * Authors:
  *      "David Niemoller" <David.Niemoller@g2-inc.com>
@@ -33,7 +33,6 @@
 #include "oval_collection_impl.h"
 #include "../common/util.h"
 
-OSCAP_HIDDEN_START;
 
 struct oval_string_map;
 
@@ -49,6 +48,5 @@ void oval_string_map_free0(struct oval_string_map *);
 void oval_string_map_free_string(struct oval_string_map *);
 struct oval_collection *oval_string_map_collect_values(struct oval_string_map *map, struct oval_collection *collection);
 
-OSCAP_HIDDEN_END;
 
 #endif				/* OVAL_STRING_MAP_IMPL_H_ */
