@@ -21,7 +21,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * Authors:
  *      "David Niemoller" <David.Niemoller@g2-inc.com>
@@ -152,7 +152,7 @@ static const struct oscap_string_map OVAL_DATETIME_FORMAT_MAP[] = {
 };
 
 oval_datetime_format_t oval_datetime_format_parse(xmlTextReaderPtr reader,
-						  char *attname, oval_arithmetic_operation_t defval)
+						  char *attname, oval_datetime_format_t defval)
 {
 	return oval_enumeration_attr(reader, attname, OVAL_DATETIME_FORMAT_MAP, defval);
 }
@@ -224,6 +224,11 @@ const char *oval_operation_get_text(oval_operation_t operation)
 	return oval_enumeration_get_text(OVAL_OPERATION_MAP, operation);
 }
 
+oval_operation_t oval_operation_from_text(const char *text)
+{
+	return oval_enumeration_from_text(OVAL_OPERATION_MAP, text);
+}
+
 static const struct oscap_string_map OVAL_CHECK_MAP[] = {
 	{OVAL_CHECK_ALL, "all"},
 	{OVAL_CHECK_AT_LEAST_ONE, "at least one"},
@@ -420,9 +425,11 @@ xmlNs *oval_family_to_namespace(oval_family_t family, const char *schema_ns, xml
 		return NULL;
 	}
 	/* We need to allocate memory also for '#' and '\0'. */
-	char family_uri[strlen(schema_ns) + 1 + strlen(family_text) + 1];
+	char *family_uri = malloc(strlen(schema_ns) + 1 + strlen(family_text) + 1);
 	sprintf(family_uri,"%s#%s", schema_ns, family_text);
-	return xmlSearchNsByHref(doc, parent, BAD_CAST family_uri);
+	xmlNs *ns = xmlSearchNsByHref(doc, parent, BAD_CAST family_uri);
+	free(family_uri);
+	return ns;
 }
 
 static const struct oscap_string_map OVAL_SUBTYPE_AIX_MAP[] = {
@@ -485,6 +492,7 @@ static const struct oscap_string_map OVAL_SUBTYPE_INDEPENDENT_MAP[] = {
 	{OVAL_INDEPENDENT_UNKNOWN, "unknown"},
 	{OVAL_INDEPENDENT_VARIABLE, "variable"},
 	{OVAL_INDEPENDENT_XML_FILE_CONTENT, "xmlfilecontent"},
+	{OVAL_INDEPENDENT_YAML_FILE_CONTENT, "yamlfilecontent"},
 	{OVAL_INDEPENDENT_SYSCHAR_SUBTYPE, "system_info"},
 	{OVAL_INDEPENDENT_LDAP57, "ldap57"},
 	{OVAL_INDEPENDENT_LDAP, "ldap"},
@@ -566,55 +574,58 @@ static const struct oscap_string_map OVAL_SUBTYPE_UNIX_MAP[] = {
 };
 
 static const struct oscap_string_map OVAL_SUBTYPE_WINDOWS_MAP[] = {
-	{OVAL_WINDOWS_ACCESS_TOKEN, "access_token"},
-	{OVAL_WINDOWS_ACTIVE_DIRECTORY, "active_directory"},
-	{OVAL_WINDOWS_AUDIT_EVENT_POLICY, "audit_event_policy"},
-	{OVAL_WINDOWS_AUDIT_EVENT_SUBCATEGORIES, "audit_event_subcatagories"},
+	{OVAL_WINDOWS_ACCESS_TOKEN, "accesstoken"},
+	{OVAL_WINDOWS_ACTIVE_DIRECTORY, "activedirectory"},
+	{OVAL_WINDOWS_AUDIT_EVENT_POLICY, "auditeventpolicy"},
+	{OVAL_WINDOWS_AUDIT_EVENT_POLICY_SUBCATEGORIES, "auditeventpolicysubcategories"},
 	{OVAL_WINDOWS_FILE, "file"},
-	{OVAL_WINDOWS_FILE_AUDITED_PERMISSIONS_53, "file_audited_permissions_53"},
-	{OVAL_WINDOWS_FILE_AUDITED_PERMISSIONS, "file_audited_permissions"},
-	{OVAL_WINDOWS_FILE_EFFECTIVE_RIGHTS_53, "file_effective_rights_53"},
-	{OVAL_WINDOWS_FILE_EFFECTIVE_RIGHTS, "file_effective_rights"},
+	{OVAL_WINDOWS_FILE_AUDITED_PERMISSIONS_53, "fileauditedpermissions53"},
+	{OVAL_WINDOWS_FILE_AUDITED_PERMISSIONS, "fileauditedpermissions"},
+	{OVAL_WINDOWS_FILE_EFFECTIVE_RIGHTS_53, "fileeffectiverights53"},
+	{OVAL_WINDOWS_FILE_EFFECTIVE_RIGHTS, "fileeffectiverights"},
 	{OVAL_WINDOWS_GROUP, "group"},
 	{OVAL_WINDOWS_GROUP_SID, "group_sid"},
 	{OVAL_WINDOWS_INTERFACE, "interface"},
-	{OVAL_WINDOWS_LOCKOUT_POLICY, "lockout_policy"},
+	{OVAL_WINDOWS_LOCKOUT_POLICY, "lockoutpolicy"},
 	{OVAL_WINDOWS_METABASE, "metabase"},
-	{OVAL_WINDOWS_PASSWORD_POLICY, "password_policy"},
+	{OVAL_WINDOWS_PASSWORD_POLICY, "passwordpolicy"},
 	{OVAL_WINDOWS_PORT, "port"},
-	{OVAL_WINDOWS_PRINTER_EFFECTIVE_RIGHTS, "printer_effective_rights"},
+	{OVAL_WINDOWS_PRINTER_EFFECTIVE_RIGHTS, "printereffectiverights"},
 	{OVAL_WINDOWS_PROCESS, "process"},
 	{OVAL_WINDOWS_REGISTRY, "registry"},
-	{OVAL_WINDOWS_REGKEY_AUDITED_PERMISSIONS_53, "regkey_audited_permissions_53"},
-	{OVAL_WINDOWS_REGKEY_AUDITED_PERMISSIONS, "regkey_audited_permissions"},
-	{OVAL_WINDOWS_REGKEY_EFFECTIVE_RIGHTS_53, "regkey_effective_rights_53"},
-	{OVAL_WINDOWS_REGKEY_EFFECTIVE_RIGHTS, "regkey_effective_rights"},
-	{OVAL_WINDOWS_SHARED_RESOURCE, "shared_resource"},
+	{OVAL_WINDOWS_REGKEY_AUDITED_PERMISSIONS_53, "regkeyauditedpermissions53"},
+	{OVAL_WINDOWS_REGKEY_AUDITED_PERMISSIONS, "regkeyauditedpermissions"},
+	{OVAL_WINDOWS_REGKEY_EFFECTIVE_RIGHTS_53, "regkeyeffectiverights53"},
+	{OVAL_WINDOWS_REGKEY_EFFECTIVE_RIGHTS, "regkeyeffectiverights"},
+	{OVAL_WINDOWS_SHARED_RESOURCE, "sharedresource"},
 	{OVAL_WINDOWS_SID, "sid"},
 	{OVAL_WINDOWS_SID_SID, "sid_sid"},
 	{OVAL_WINDOWS_USER_ACCESS_CONTROL, "user_access_control"},
 	{OVAL_WINDOWS_USER, "user"},
-	{OVAL_WINDOWS_USER_SID_55, "user_sid_55"},
+	{OVAL_WINDOWS_USER_SID_55, "user_sid55"},
 	{OVAL_WINDOWS_USER_SID, "user_sid"},
 	{OVAL_WINDOWS_VOLUME, "volume"},
 	{OVAL_WINDOWS_WMI, "wmi"},
-	{OVAL_WINDOWS_WUA_UPDATE_SEARCHER, "wua_update_searcher"},
+	{OVAL_WINDOWS_WUA_UPDATE_SEARCHER, "wuaupdatesearcher"},
+	{OVAL_WINDOWS_ACTIVE_DIRECTORY_57, "activedirectory57"},
+	{OVAL_WINDOWS_CMDLET, "cmdlet"},
+	{OVAL_WINDOWS_DNSCACHE, "dnscache"},
+	{OVAL_WINDOWS_LICENSE, "license"},
+	{OVAL_WINDOWS_NTUSER, "ntuser"},
+	{OVAL_WINDOWS_PEHEADER, "peheader"},
+	{OVAL_WINDOWS_PROCESS_58, "process58"},
+	{OVAL_WINDOWS_SERVICE, "service"},
+	{OVAL_WINDOWS_SERVICE_EFFECTIVE_RIGHTS, "serviceeffectiverights"},
+	{OVAL_WINDOWS_SHARED_RESOURCE_AUDITED_PERMISSIONS, "sharedresourceauditedpermissions"},
+	{OVAL_WINDOWS_SHARED_RESOURCE_EFFECTIVE_RIGHTS, "sharedresourceeffectiverights"},
+	{OVAL_WINDOWS_SYSTEM_METRIC, "systemmetric"},
+	{OVAL_WINDOWS_USER_RIGHT, "userright"},
+	{OVAL_WINDOWS_WMI_57, "wmi57"},
 	{OVAL_SUBTYPE_UNKNOWN, NULL}
 };
 
-oval_subtype_t oval_subtype_parse(xmlTextReaderPtr reader)
+static const struct oscap_string_map *get_map_for_family(oval_family_t family)
 {
-	oval_family_t family = oval_family_parse(reader);
-	if (family == OVAL_FAMILY_UNKNOWN)
-		return OVAL_SUBTYPE_UNKNOWN;
-
-	oval_subtype_t subtype = OVAL_SUBTYPE_UNKNOWN;
-	char *tagname = (char *)xmlTextReaderLocalName(reader);
-	char *endptr = (tagname != NULL) ? strrchr(tagname, '_') : NULL;
-	if (endptr == NULL)
-		goto cleanup;
-	*endptr = '\0';
-
 	const struct oscap_string_map *map = NULL;
 	switch (family) {
 	case OVAL_FAMILY_AIX:
@@ -660,6 +671,27 @@ oval_subtype_t oval_subtype_parse(xmlTextReaderPtr reader)
 		map = OVAL_SUBTYPE_WINDOWS_MAP;
 		break;
 	default:
+		map = NULL;
+		break;
+	}
+	return map;
+}
+
+oval_subtype_t oval_subtype_parse(xmlTextReaderPtr reader)
+{
+	oval_family_t family = oval_family_parse(reader);
+	if (family == OVAL_FAMILY_UNKNOWN)
+		return OVAL_SUBTYPE_UNKNOWN;
+
+	oval_subtype_t subtype = OVAL_SUBTYPE_UNKNOWN;
+	char *tagname = (char *)xmlTextReaderLocalName(reader);
+	char *endptr = strrchr(tagname, '_');
+	if (endptr == NULL)
+		goto cleanup;
+	*endptr = '\0';
+
+	const struct oscap_string_map *map = get_map_for_family(family);
+	if (map == NULL) {
 		goto cleanup;
 	}
 
@@ -680,53 +712,8 @@ oval_family_t oval_subtype_get_family(oval_subtype_t subtype)
 
 const char *oval_subtype_get_text(oval_subtype_t subtype)
 {
-	const struct oscap_string_map *map = NULL;
-	switch (oval_subtype_get_family(subtype)) {
-	case OVAL_FAMILY_AIX:
-		map = OVAL_SUBTYPE_AIX_MAP;
-		break;
-	case OVAL_FAMILY_APACHE:
-		map = OVAL_SUBTYPE_APACHE_MAP;
-		break;
-	case OVAL_FAMILY_CATOS:
-		map = OVAL_SUBTYPE_CATOS_MAP;
-		break;
-	case OVAL_FAMILY_ESX:
-		map = OVAL_SUBTYPE_ESX_MAP;
-		break;
-	case OVAL_FAMILY_FREEBSD:
-		map = OVAL_SUBTYPE_FREEBSD_MAP;
-		break;
-	case OVAL_FAMILY_HPUX:
-		map = OVAL_SUBTYPE_HPUX_MAP;
-		break;
-	case OVAL_FAMILY_INDEPENDENT:
-		map = OVAL_SUBTYPE_INDEPENDENT_MAP;
-		break;
-	case OVAL_FAMILY_IOS:
-		map = OVAL_SUBTYPE_IOS_MAP;
-		break;
-	case OVAL_FAMILY_LINUX:
-		map = OVAL_SUBTYPE_LINUX_MAP;
-		break;
-	case OVAL_FAMILY_MACOS:
-		map = OVAL_SUBTYPE_MACOS_MAP;
-		break;
-	case OVAL_FAMILY_PIXOS:
-		map = OVAL_SUBTYPE_PIXOS_MAP;
-		break;
-	case OVAL_FAMILY_SOLARIS:
-		map = OVAL_SUBTYPE_SOLARIS_MAP;
-		break;
-	case OVAL_FAMILY_UNIX:
-		map = OVAL_SUBTYPE_UNIX_MAP;
-		break;
-	case OVAL_FAMILY_WINDOWS:
-		map = OVAL_SUBTYPE_WINDOWS_MAP;
-		break;
-	default:
-		map = NULL;
-	}
+	oval_family_t family = oval_subtype_get_family(subtype);
+	const struct oscap_string_map *map = get_map_for_family(family);
 
 	if (map) {
 		return oval_enumeration_get_text(map, subtype);
@@ -736,6 +723,22 @@ const char *oval_subtype_get_text(oval_subtype_t subtype)
 	}
 }
 
+const char *oval_subtype_to_str(oval_subtype_t subtype)
+{
+	return oval_subtype_get_text(subtype);
+}
+
+oval_subtype_t oval_subtype_from_str(const char *family_str, const char *subtype_str)
+{
+	oval_subtype_t subtype = OVAL_SUBTYPE_UNKNOWN;
+	oval_family_t family = oval_enumeration_from_text(OVAL_FAMILY_MAP, family_str);
+	const struct oscap_string_map *map = get_map_for_family(family);
+	if (map != NULL) {
+		subtype = oval_enumeration_from_text(map, subtype_str);
+	}
+	return subtype;
+}
+
 static const struct oscap_string_map OVAL_RESULT_MAP[] = {
 	{OVAL_RESULT_TRUE, "true"},
 	{OVAL_RESULT_FALSE, "false"},
