@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * Authors:
  *      "Daniel Kopecek" <dkopecek@redhat.com>
@@ -26,26 +26,21 @@
 
 #include <pthread.h>
 
-#include "public/sm_alloc.h"
 #include "generic/bitmap.h"
-#include "_sexp-parser.h"
-#include "_seap-scheme.h"
 #include "seap-descriptor.h"
 #include "_sexp-atomic.h"
 
 SEAP_desctable_t *SEAP_desctable_new (void)
 {
-        SEAP_desctable_t *t;
-
-        t = sm_talloc(SEAP_desctable_t);
+	SEAP_desctable_t *t = malloc(sizeof(SEAP_desctable_t));
         t->tree = NULL;
         t->bmap = NULL;
 
         return(t);
 }
 
-int SEAP_desc_add (SEAP_desctable_t *sd_table, SEXP_pstate_t *pstate,
-                         SEAP_scheme_t scheme, void *scheme_data)
+int SEAP_desc_add(SEAP_desctable_t *sd_table, SEAP_scheme_t scheme,
+                   void *scheme_data)
 {
         bitmap_bitn_t sd;
         pthread_mutexattr_t mutex_attr;
@@ -62,17 +57,19 @@ int SEAP_desc_add (SEAP_desctable_t *sd_table, SEXP_pstate_t *pstate,
                 if (sd_table->tree == NULL)
                         sd_table->tree = rbt_i32_new();
 
-                sd_dsc = sm_talloc(SEAP_desc_t);
+		sd_dsc = malloc(sizeof(SEAP_desc_t));
 
                 sd_dsc->next_id = 0;
                 /* sd_dsc->sexpcnt = 0; */
-                sd_dsc->pstate  = pstate;
                 sd_dsc->scheme  = scheme;
                 sd_dsc->scheme_data = scheme_data;
                 sd_dsc->ostate  = NULL;
                 sd_dsc->next_cid = 0;
                 sd_dsc->cmd_c_table = SEAP_cmdtbl_new ();
                 sd_dsc->cmd_w_table = SEAP_cmdtbl_new ();
+		sd_dsc->msg_queue = NULL;
+		sd_dsc->err_queue = rbt_i32_new();
+		sd_dsc->cmd_queue = NULL;
 
 		SEAP_packetq_init(&sd_dsc->pck_queue);
 
@@ -118,6 +115,11 @@ int SEAP_desc_del (SEAP_desctable_t *sd_table, int sd)
         return (0);
 }
 
+static void __SEAP_desc_errqueue_free_cb(struct rbt_i32_node *n)
+{
+    SEAP_error_free(n->data);
+}
+
 void SEAP_desc_free(SEAP_desc_t *dsc)
 {
         SEAP_cmdtbl_free(dsc->cmd_c_table);
@@ -125,7 +127,8 @@ void SEAP_desc_free(SEAP_desc_t *dsc)
 	SEAP_packetq_free(&dsc->pck_queue);
         pthread_mutex_destroy(&(dsc->r_lock));
         pthread_mutex_destroy(&(dsc->w_lock));
-        sm_free(dsc);
+	rbt_i32_free_cb(dsc->err_queue, __SEAP_desc_errqueue_free_cb);
+	free(dsc);
 }
 
 static void SEAP_desc_free_node(struct rbt_i32_node *n)
@@ -139,7 +142,7 @@ void SEAP_desctable_free(SEAP_desctable_t *sd_table)
                 rbt_i32_free_cb(sd_table->tree, &SEAP_desc_free_node);
         if (sd_table->bmap != NULL)
                 bitmap_free(sd_table->bmap);
-        sm_free(sd_table);
+	free(sd_table);
 }
 
 SEAP_desc_t *SEAP_desc_get (SEAP_desctable_t *sd_table, int sd)
