@@ -1,4 +1,5 @@
-#!/bin/bash
+#!/usr/bin/env bash
+. $builddir/tests/test_common.sh
 
 result=`mktemp`
 stderr=`mktemp`
