@@ -1,4 +1,5 @@
-#!/bin/bash
+#!/usr/bin/env bash
+. $builddir/tests/test_common.sh
 
 set -e
 set -o pipefail
@@ -14,7 +15,7 @@ echo "Output file = $output"
 echo "Result file = $result"
 [ -f $output ]; [ "`cat $output`" == "XCCDF Results are exported correctly." ]; rm $output
 
-$OSCAP xccdf validate-xml $result
+$OSCAP xccdf validate $result
 
 assert_exists 1 '//Profile'
 assert_exists 2 '//Profile/select'
